@@ -102,6 +102,13 @@ class ToyJob(PythonTemplateJob):
     def _check_if_input_should_be_written(self):
         return True
 
+    # Check for valid input
+    def validate_ready_to_run(self):
+        if not isinstance(self.input.data_in, int):
+            raise ValueError(
+                f"data_in in should be of type int, not {type(self.input.data_in)}."
+            )
+
     # This function is executed
     def run_static(self):
         self.status.running = True
